import * as react_jsx_runtime from 'react/jsx-runtime';
import { Component } from 'react';
import { TextStyle, ViewStyle, StyleProp } from 'react-native';
import { GeolocationResponse } from '@react-native-community/geolocation';

declare const Icons: {
    watch: string;
    timer3: string;
    timer10: string;
    timerAv: string;
    timer: string;
    menu: string;
    zoomOutMap: string;
    zoomOut: string;
    zoomIn: string;
    linearScale: string;
    room: string;
    place: string;
    zoomOutMap2: string;
    locationOff: string;
    locationCity: string;
    locationDisabled: string;
    locationSearching: string;
    myLocation: string;
    editLocation: string;
    addLocation: string;
    map: string;
    directionsTransit: string;
    directionsWalk: string;
    directionsBike: string;
    cardTravel: string;
    home: string;
    directionsDriving: string;
    navigate: string;
    target: string;
    location2: string;
    location3: string;
    compassDirection: string;
    compassDot: string;
    arriveLeft: string;
    arriveRight: string;
    arriveStraight: string;
    arrive: string;
    close: string;
    continueLeft: string;
    continueRight: string;
    continueSlightLeft: string;
    continueSlightRight: string;
    continueStraight: string;
    continueUturn: string;
    continue: string;
    keepLeft: string;
    keepRight: string;
    departLeft: string;
    departRight: string;
    departStraight: string;
    depart: string;
    endOfRoadLeft: string;
    endOfRoadRight: string;
    flag: string;
    forkLeft: string;
    forkRight: string;
    forkSlightLeft: string;
    forkSlightRight: string;
    forkStraight: string;
    fork: string;
    invalidLeft: string;
    invalidRight: string;
    invalidSlightLeft: string;
    invalidSlightRight: string;
    invalidStraight: string;
    invalidUturn: string;
    invalid: string;
    straight: string;
    merge: string;
    mergeLeft: string;
    mergeRight: string;
    mergeSlightLeft: string;
    mergeSlightRight: string;
    mergeStraight: string;
    newNameLeft: string;
    newNameRight: string;
    newNameSharpLeft: string;
    newNameSharpRight: string;
    newNameSlightLeft: string;
    newNameSlightRight: string;
    newNameStraight: string;
    notificaitonSharpRight: string;
    notificationLeft: string;
    notificationRight: string;
    notificationSharpLeft: string;
    notificationSlightLeft: string;
    notificationSlightRight: string;
    notificationStraight: string;
    offRampLeft: string;
    offRampRight: string;
    offRampSlightLeft: string;
    offRampSlightRight: string;
    rampLeft: string;
    rampRight: string;
    rampSlightLeft: string;
    rampSlightRight: string;
    onRampLeft: string;
    onRampRight: string;
    onRampSharpLeft: string;
    onRampSharpRight: string;
    onRampSlightLeft: string;
    onRampSlightRight: string;
    onRampStraight: string;
    rotaryLeft: string;
    rotaryRight: string;
    rotarySharpLeft: string;
    rotarySharpRight: string;
    rotarySlightLeft: string;
    rotarySlightRight: string;
    rotaryStraight: string;
    rotary: string;
    roundaboutLeft: string;
    roundaboutRight: string;
    roundaboutSharpLeft: string;
    roundaboutSharpRight: string;
    roundaboutSlightLeft: string;
    roundaboutSlightRight: string;
    roundaboutStraight: string;
    roundabout: string;
    turnLeft: string;
    turnRight: string;
    turnSharpLeft: string;
    turnSharpRight: string;
    turnSlightLeft: string;
    turnSlightRight: string;
    turnStraight: string;
    updown: string;
};

declare const MODE_MAPPING: {
    DRIVING: {
        mode: string;
        name: string;
        icon: string;
    };
    WALKING: {
        mode: string;
        name: string;
        icon: string;
    };
    TRANSIT: {
        mode: string;
        name: string;
        icon: string;
    };
    BICYCLING: {
        mode: string;
        name: string;
        icon: string;
    };
};

declare const _default: {
    IDLE: string;
    ROUTE: string;
    NAVIGATION: string;
};

type CloseButtonProps = {
    maneuver?: object;
    size?: number;
    opacity?: number;
    color?: string;
    onPress: () => void;
};
type StylesPropsCloseButton = {
    closeButtonText: TextStyle;
};
type Route = {
    origin: {
        address: string;
    };
    destination: {
        address: string;
    };
    duration: {
        text: string;
    };
    distance: {
        text: string;
    };
    steps: any[];
};
type DirectionsListViewProps = {
    route: Route;
    fontFamily?: string;
    fontFamilyBold?: string;
    showOriginDestinationHeader?: boolean;
    displayTravelMode?: boolean;
};
type StylesPropsDirections = {
    directionDetailHeader: ViewStyle;
    directionDetailHeaderSection: ViewStyle;
    directionDetailHeaderAddressLabel: TextStyle;
    directionDetailHeaderAddressText: TextStyle;
    directionDetailTravel: ViewStyle;
    directionDetailTravelDuration: TextStyle;
    directionDetailTravelDistance: TextStyle;
    directionDetailSectionContainer: ViewStyle;
};
type DirectionListViewItemProps = {
    instructions?: string;
    distance?: {
        text: string;
    };
    duration?: {
        text: string;
    };
    maneuver?: {
        name: NavigationIconType | "invalid";
        type: string;
    };
    fontFamily?: string;
    fontFamilyBold?: string;
    fontSize?: number;
    displayTravelMode?: boolean;
};
type StylesPropsItems = {
    directionDetailSection: ViewStyle;
    directionDetailIconContainer: ViewStyle;
    directionDetailContent: ViewStyle;
};
type DurationDistanceLabelProps = {
    style?: TextStyle;
    instructions?: string;
    fontFamily?: string;
    fontSize?: number;
    distance?: {
        text: string;
    };
    duration?: {
        text: string;
    };
    opacity?: number;
    withTravelModeIcon?: boolean;
    mode?: string;
};
type ManeuverViewStep = {
    distance?: {
        text: string;
    };
    duration?: {
        text: string;
    };
    maneuver?: {
        name?: NavigationIconType | "invalid";
    };
    instructions?: string;
};
type ManeuverViewProps = {
    step: ManeuverViewStep;
    fontFamily?: string;
    fontFamilyBold?: string;
    fontSize?: number;
    arrowSize?: number;
    arrowColor?: string;
    withCloseButton?: boolean;
    onClose?: () => void;
    onPress?: () => void;
    fontColor?: string;
    backgroundColor?: string;
};
type DurationDistanceViewStep = {
    distance?: {
        text: string;
    };
    duration?: {
        text: string;
    };
};
type DurationDistanceViewProps = {
    step: DurationDistanceViewStep;
    fontFamily?: string;
    fontFamilyBold?: string;
    fontSize?: number;
    arrowSize?: number;
    arrowColor?: string;
    withCloseButton?: boolean;
    onClose?: () => void;
    onPress?: () => void;
};
type Maneuver = {
    name?: NavigationIconType | "invalid";
};
type ManeuverArrowProps = {
    maneuver?: Maneuver;
    size?: number;
    opacity?: number;
    color?: string;
};
type ManeuverLabelProps = {
    instructions?: string;
    fontFamily?: string;
    fontFamilyBold?: string;
    fontSize?: number;
    fontColor?: string;
};
type ManeuverLabelStyleMapping = {
    regular: TextStyle;
    bold: TextStyle;
    durationDistance: TextStyle;
    extra: TextStyle;
};
type DirectionFetchOptions = {
    key?: string;
    mode?: string;
    [key: string]: any;
};
type DirectionRoute = {
    summary: string;
    legs: DirectionLeg[];
    bounds: {
        northeast: DirectionLatLng;
        southwest: DirectionLatLng;
    };
    polylines: DirectionPolyline[];
};
type DirectionLeg = {
    start_location: DirectionLatLng;
    end_location: DirectionLatLng;
    start_address: string;
    end_address: string;
    duration: DirectionDuration;
    distance: DirectionDistance;
    steps: DirectionStep[];
};
type DirectionStep = {
    start_location: DirectionLatLng;
    end_location: DirectionLatLng;
    maneuver: string;
    travel_mode: string;
    polyline: {
        points: string;
    };
    duration: DirectionDuration;
    distance: DirectionDistance;
    html_instructions: string;
};
type DirectionLatLng = {
    lat: number;
    lng: number;
};
type DirectionDuration = {
    text: string;
    value: number;
};
type DirectionDistance = {
    text: string;
    value: number;
};
type DirectionPolyline = {
    coordinates: DirectionCoordinate[];
    type: string;
};
type DirectionCoordinate = {
    latitude: number;
    longitude: number;
};
type DirectionStepDetails = {
    final?: boolean;
    bearing: number;
    compass: {
        detail: string;
        simple: string;
    };
    start: DirectionCoordinate;
    end: DirectionCoordinate;
    maneuver: {
        name: NavigationIconType | "invalid";
        type: string;
    };
    polyline: DirectionPolyline;
    instructions: string;
    mode?: string;
    duration?: DirectionDuration;
    distance?: DirectionDistance;
};
type MapViewNavigationProps = {
    origin?: string | Coordinate | undefined;
    destination?: string | Coordinate | undefined;
    apiKey: string;
    language?: string;
    map?: () => any;
    navigationMode?: string;
    travelMode?: string;
    maxZoom?: number;
    minZoom?: number;
    animationDuration?: number;
    navigationViewingAngle?: number;
    navigationZoomLevel?: number;
    directionZoomQuantifier?: number;
    onRouteChange?: (route: any) => void;
    onStepChange?: (step: any, nextStep?: any) => void;
    onNavigationStarted?: () => void;
    onNavigationCompleted?: () => void;
    routeStepDistance?: number;
    routeStepInnerTolerance?: number;
    routeStepCenterTolerance?: number;
    routeStepCourseTolerance?: number;
    displayDebugMarkers?: boolean;
    simulate?: boolean;
    options?: object;
    onPositionChanged?: (position: {
        longitude: number;
        latitude: number;
    }) => void;
    deviceDimensionWidth?: number | boolean;
    theme?: any;
};
type MapViewNavigationState = {
    [key: string]: any;
};
type PositionMarkerProps = {
    coordinate?: {
        latitude: number;
        longitude: number;
    };
    size?: number;
    fontSize?: number;
    type?: string;
    color?: string;
    angle?: number;
    backgroundColor?: string;
    borderColor?: string;
    borderWidth?: number;
    theme?: any;
};
type PositionMarkerStyles = {
    positionMarkerArrow: StyleProp<ViewStyle>;
    positionMarkerText: StyleProp<TextStyle>;
};
type RouterMarkerProps = {
    coordinate: {
        latitude: number;
        longitude: number;
    };
    theme?: any;
    type?: string;
    key: string;
};
type RouterMarkerStyles = {
    markerText: StyleProp<TextStyle>;
};
type RoutePolylineProps = {
    coordinates: {
        latitude: number;
        longitude: number;
    }[];
    theme?: any;
    type?: string;
};
type RoutePolylineTheme = {
    strokeWidth: number;
    strokeColor: string;
    fillColor?: string;
    borderWidth?: number;
};
type TravelModeBoxProps = {
    backgroundColor?: string;
    borderColor?: string;
    borderWidth?: number;
    borderRadius?: number;
    contentPadding?: number;
    inverseTextColor?: string;
    modes?: string[];
    selected?: any;
    defaultValue?: any;
    style?: StyleProp<ViewStyle>;
    onChange?: (value: any) => void;
    theme?: string;
    invertKeyLabel?: boolean;
    fontFamily?: string;
    fontSize?: number;
    useIcons?: boolean;
};
type TravelModeBoxDefaultProps = {
    backgroundColor: string;
    borderColor: string;
    borderWidth: number;
    borderRadius: number;
    contentPadding: number;
    inverseTextColor: string;
    defaultValue: any;
    selected: any;
    style: StyleProp<ViewStyle>;
    onChange?: (value: any) => void;
    theme?: string;
    invertKeyLabel: boolean;
    fontSize: number;
    fontFamily?: string;
    useIcons: boolean;
    modes: string[];
};
type TravelModeLabelProps = {
    size?: number;
    opacity?: number;
    color?: string;
    fontFamily?: string;
    fontSize?: number;
    useIcon?: boolean;
    useLabel?: boolean;
    mode?: string;
};
type TravelModeLabelDefaultProps = {
    color: string | undefined;
    opacity: number;
    fontSize: number;
    fontFamily: string | undefined;
    useIcon: boolean;
    useLabel: boolean;
    mode: string | undefined;
};
type TrapCoordinate = {
    longitude: number;
    latitude: number;
};
type Trap = {
    type: string;
    coordinate?: TrapCoordinate;
    radius?: number;
    innerRadius?: number;
    centerRadius?: number;
    outerRadius?: number;
    courseTolerance?: number;
    step?: any;
    nextStep?: any;
    options?: any;
    index?: number;
    state?: string;
    callback?: (trap: Trap, event: string, state: string) => void;
};
type TrapTypes = {
    States: {
        OUTSIDE: string;
        ENTERED: string;
        INSIDE: string;
        CENTER: string;
        LEAVING: string;
        LEFT: string;
        EXPIRED: string;
    };
    Types: {
        CIRCLE: string;
        STEP: string;
    };
    Events: {
        ENTERING_ON_COURSE: string;
        ENTERING_OFF_COURSE: string;
        INSIDE: string;
        INSIDE_CENTER: string;
        LEAVING_ON_COURSE: string;
        LEAVING_OFF_COURSE: string;
        LEAVING: string;
    };
};
type LatLng = {
    latitude: number;
    longitude: number;
};
type LatLngWithOptional = {
    latitude?: number;
    longitude?: number;
};
type Coordinate = {
    latitude: number;
    longitude: number;
};
interface Point extends Coordinate {
    bearing?: number;
    final?: boolean;
}
type RouteStep = {
    polyline: {
        coordinates: Coordinate[];
    };
};
type SimulatorRoute = {
    steps: RouteStep[];
};
type Instance = {
    updateBearing(bearing: number, speed: number): void;
    setPosition(position: {
        heading: number;
        bearing?: number;
        latitude: number;
        final?: boolean;
        longitude: number;
    }): void;
};
type AddressComponent = {
    short_name: string;
    long_name: string;
    types: string[];
};
type Geometry = {
    location: {
        lat: number;
        lng: number;
    };
};
type GeocodingResult = {
    formatted_address: string;
    geometry: Geometry;
    address_components: AddressComponent[];
};
type GeocodingApiResponse = {
    status: string;
    results: GeocodingResult[];
};
type GeocoderOptions = {
    language?: string;
};
type MinimizedAddressComponent = {
    short: string;
    long: string;
};
type MinimizedResult = {
    components: {
        [key: string]: MinimizedAddressComponent;
    };
    address: string;
    coordinate: {
        latitude: number;
        longitude: number;
    };
};
type NavigationIconType = keyof typeof Icons;
type ModeMappingType = keyof typeof MODE_MAPPING;
type NavigationModeTypes = keyof typeof _default;

declare class CloseButton extends Component<CloseButtonProps, {}> {
    static defaultProps: CloseButtonProps;
    constructor(props: CloseButtonProps);
    render(): react_jsx_runtime.JSX.Element;
    createStyles(props: CloseButtonProps): StylesPropsCloseButton;
}

declare class DirectionsListView extends Component<DirectionsListViewProps, {}> {
    static defaultProps: Partial<DirectionsListViewProps>;
    constructor(props: DirectionsListViewProps);
    render(): react_jsx_runtime.JSX.Element;
    createStyles(props: DirectionsListViewProps): StylesPropsDirections;
}

declare class DurationDistanceLabel extends Component<DurationDistanceLabelProps, {}> {
    static defaultProps: Partial<DurationDistanceLabelProps>;
    constructor(props: DurationDistanceLabelProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class DurationDistanceView extends Component<DurationDistanceViewProps, {}> {
    static defaultProps: Partial<DurationDistanceViewProps>;
    constructor(props: DurationDistanceViewProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class ManeuverArrow extends Component<ManeuverArrowProps, {}> {
    static defaultProps: Partial<ManeuverArrowProps>;
    constructor(props: ManeuverArrowProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class ManeuverLabel extends Component<ManeuverLabelProps, {}> {
    static defaultProps: Partial<ManeuverLabelProps>;
    constructor(props: ManeuverLabelProps);
    getParsedInstructions(styles: ManeuverLabelStyleMapping): react_jsx_runtime.JSX.Element;
    render(): react_jsx_runtime.JSX.Element;
}

declare class ManeuverView extends Component<ManeuverViewProps, {}> {
    static defaultProps: Partial<ManeuverViewProps>;
    constructor(props: ManeuverViewProps);
    render(): react_jsx_runtime.JSX.Element;
}

type PositionType = GeolocationResponse["coords"] & {
    coordinate: {
        longitude: number;
        latitude: number;
    };
};
declare class MapViewNavigation extends Component<MapViewNavigationProps, MapViewNavigationState> {
    static defaultProps: {
        origin: boolean;
        destination: boolean;
        apiKey: string;
        language: any;
        map: any;
        navigationMode: string;
        travelMode: string;
        maxZoom: number;
        minZoom: number;
        animationDuration: number;
        navigationViewingAngle: number;
        navigationZoomLevel: number;
        directionZoomQuantifier: number;
        onRouteChange: any;
        onStepChange: any;
        onNavigationStarted: any;
        onNavigationCompleted: any;
        routeStepDistance: number;
        routeStepInnerTolerance: number;
        routeStepCenterTolerance: number;
        routeStepCourseTolerance: number;
        displayDebugMarkers: boolean;
        simulate: boolean;
        onPositionChanged: any;
        options: {};
        deviceDimensionWidth: boolean;
        theme: any;
    };
    private geoCoder;
    private directionsCoder;
    private traps;
    private simulator?;
    private readonly aspectRatio;
    private stepIndex;
    private watchId?;
    private theme?;
    constructor(props: MapViewNavigationProps);
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: MapViewNavigationProps, prevState: MapViewNavigationState): void;
    getCoordinates(address: string, raw?: boolean): Promise<Coordinate[]>;
    getZoomValue(level: number): {
        latitudeDelta: number;
        longitudeDelta: number;
    };
    getBoundingBoxZoomValue(b: [Coordinate, Coordinate], quantifier?: number): {
        latitudeDelta?: undefined;
        longitudeDelta?: undefined;
    } | {
        latitudeDelta: number;
        longitudeDelta: number;
    };
    updateBearing(bearing: number, lon: number, lat: number, duration?: number): void;
    updateStep(stepIndex?: number): void;
    setPosition(position: PositionType): void;
    clearRoute(): void;
    updateRoute(origin: Coordinate | string, destination: Coordinate | string, navigationMode: NavigationModeTypes, options?: object | null): void;
    prepareRoute(origin: string | Coordinate, destination: string | Coordinate, options?: object, testForRoute?: boolean): Promise<any>;
    displayRoute(origin: string | Coordinate, destination: string | Coordinate, options?: object): void;
    navigateRoute(origin: string | Coordinate, destination: string | Coordinate, options?: object): Promise<any>;
    getDebugShapes(): any[];
    render(): react_jsx_runtime.JSX.Element;
}

declare class PositionMarker extends Component<PositionMarkerProps, {}> {
    static defaultProps: {
        coordinate: any;
        size: number;
        fontSize: number;
        type: string;
        color: string;
        angle: number;
        borderWidth: number;
        borderColor: any;
        backgroundColor: string;
    };
    theme: any;
    constructor(props: PositionMarkerProps);
    render(): react_jsx_runtime.JSX.Element;
    renderArrow(styles: PositionMarkerStyles): react_jsx_runtime.JSX.Element;
    renderDot(styles: PositionMarkerStyles): react_jsx_runtime.JSX.Element;
}

declare class RouterMarker extends Component<RouterMarkerProps, {}> {
    theme: any;
    constructor(props: RouterMarkerProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class RoutePolyline extends Component<RoutePolylineProps, {}> {
    theme: RoutePolylineTheme | undefined;
    constructor(props: RoutePolylineProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class TravelModeBox extends Component<TravelModeBoxProps, {}> {
    static defaultProps: TravelModeBoxDefaultProps;
    constructor(props: TravelModeBoxProps);
    render(): react_jsx_runtime.JSX.Element;
}

declare class TravelModeLabel extends Component<TravelModeLabelProps, {}> {
    static defaultProps: TravelModeLabelDefaultProps;
    constructor(props: TravelModeLabelProps);
    render(): react_jsx_runtime.JSX.Element;
}

export { type AddressComponent, CloseButton, type CloseButtonProps, type Coordinate, type DirectionCoordinate, type DirectionDistance, type DirectionDuration, type DirectionFetchOptions, type DirectionLatLng, type DirectionLeg, DirectionsListView as DirectionListViewItem, type DirectionListViewItemProps, type DirectionPolyline, type DirectionRoute, type DirectionStep, type DirectionStepDetails, DirectionsListView, type DirectionsListViewProps, DurationDistanceLabel, type DurationDistanceLabelProps, DurationDistanceView, type DurationDistanceViewProps, type DurationDistanceViewStep, type GeocoderOptions, type GeocodingApiResponse, type GeocodingResult, type Geometry, type Instance, type LatLng, type LatLngWithOptional, ManeuverArrow, type ManeuverArrowProps, ManeuverLabel, type ManeuverLabelProps, type ManeuverLabelStyleMapping, ManeuverView, type ManeuverViewProps, type ManeuverViewStep, MapViewNavigation, type MapViewNavigationProps, type MapViewNavigationState, type MinimizedAddressComponent, type MinimizedResult, type ModeMappingType, type NavigationIconType, type NavigationModeTypes, type Point, PositionMarker, type PositionMarkerProps, type PositionMarkerStyles, type Route, RouterMarker as RouteMarker, RoutePolyline, type RoutePolylineProps, type RoutePolylineTheme, type RouteStep, type RouterMarkerProps, type RouterMarkerStyles, type SimulatorRoute, type StylesPropsCloseButton, type StylesPropsDirections, type StylesPropsItems, type Trap, type TrapCoordinate, type TrapTypes, TravelModeBox, type TravelModeBoxDefaultProps, type TravelModeBoxProps, TravelModeLabel, type TravelModeLabelDefaultProps, type TravelModeLabelProps };
